Learn R Programming

portfolio.optimization (version 1.0-0)

optimal.portfolio: Meta-function to optimize portfolios given a portfolio.model instance

Description

optimal.portfolio optimizes the portfolio of a model given the current specification

Usage

optimal.portfolio(input = NULL, ...)

p.opt(input = NULL, ...)

opt.p(input = NULL, ...)

Arguments

input

either a portfolio.model or something to convert to a new model

...

other parameters to be passed on to the optimization sub-functions.

Value

an S3 object of class portfolio.model with the optimized portfolio.

Examples

Run this code
# NOT RUN {
data(sp100w17av30s)
model <- optimal.portfolio(scenario.set)

# }

Run the code above in your browser using DataLab