powered by
optimal.portfolio optimizes the portfolio of a model given the current specification
optimal.portfolio
optimal.portfolio(input = NULL, ...)p.opt(input = NULL, ...)opt.p(input = NULL, ...)
p.opt(input = NULL, ...)
opt.p(input = NULL, ...)
either a portfolio.model or something to convert to a new model
other parameters to be passed on to the optimization sub-functions.
an S3 object of class portfolio.model with the optimized portfolio.
# NOT RUN { data(sp100w17av30s) model <- optimal.portfolio(scenario.set) # }
Run the code above in your browser using DataLab